# CrapsSim

Simulator for craps with various betting strategies

## About

CrapsSim contains Python code to run all of the necessary elements of a craps table.  Currently supports running with `verbose=True` which prints out all actions at the table, or `verbose=False` for running many simulations.  Betting logic needs to be pre-specified.

## Results

I will post results from this simulator on my personal site: http://pages.stat.wisc.edu/~kent/.  

Current blog posts include:
- [All Bets Are Off: Re-learning the Pass Line Bet in Craps](http://pages.stat.wisc.edu/~kent/blog/2019.02.28_Craps_Passline/passline-and-odds.html)


## Use of this Repo

I welcome anyone to clone or fork this repository for their own purposes.  There are no guarantees that this code is bug/error free, especially after personal modifications.  I ask that any published work that uses this code refer back to this repository for due credit.  

If you would like to see a particular strategy implemented by this simulator, please reach out via email: spkent@wisc.edu.  